pub struct VersionPart {
pub value: String,
pub cycle_index: Option<usize>,
}Expand description
A single version component.
Holds the string value as it appears in the serialised version and the
index into a cyclic values list (or None for numeric parts).
Fields
value: StringCurrent string value of this component.
cycle_index: Option<usize>Index of value within the cyclic values list for this part.
None for numeric parts.